@@ -6,7 +6,7 @@ use 5.010;
 # ABSTRACT: App::TimeTracker Trello plugin
 use App::TimeTracker::Utils qw(error_message warning_message);
 
-our $VERSION = "1.004";
+our $VERSION = "1.005";
 
 use Moose::Role;
 use WWW::Trello::Lite;
@@ -62,9 +62,9 @@ around BUILDARGS => sub {
     my $class = shift;
 
     my %args = @_;
-    if ($args{trello} && $args{trello} =~ /^https/) {
-        $args{trello}=~m|https://trello.com/c/([^/]+)/?|;
-        $args{trello}= $1;
+    if ( $args{trello} && $args{trello} =~ /^https/ ) {
+        $args{trello} =~ m|https://trello.com/c/([^/]+)/?|;
+        $args{trello} = $1;
     }
     return $class->$orig(%args);
 };
@@ -92,6 +92,10 @@ before [ 'cmd_start', 'cmd_continue', 'cmd_append' ] => sub {
     my $card = $self->trello_card;
     return unless $card;
 
+    if ( $self->config->{trello}{listname_as_tag} ) {
+        $self->_tag_listname($card);
+    }
+
     $name = $self->_trello_just_the_name($card);
     if ( defined $self->description ) {
         $self->description( $self->description . ' ' . $name );
@@ -153,7 +157,7 @@ after 'cmd_stop' => sub {
 
     my $task_rounded_minutes = $task->rounded_minutes;
 
-    my $card = $self->_trello_fetch_card( $oldid );
+    my $card = $self->_trello_fetch_card($oldid);
     unless ($card) {
         warning_message(
             "Last task did not contain a trello id, not updating time etc.");
@@ -180,7 +184,7 @@ after 'cmd_stop' => sub {
             if ( my $lists = $self->_trello_fetch_lists ) {
                 if ( $lists->{$move_to} ) {
                     $update{idList} = $lists->{$move_to}->{id};
-                    $update{pos} = 'top';
+                    $update{pos}    = 'top';
                 }
                 else {
                     warning_message("Could not find list >$move_to<");
@@ -230,7 +234,8 @@ sub cmd_setup_trello {
     }
 
     if ( $conf->{token} ) {
-        my $token_info = $self->trello_client->get('tokens/' . $conf->{token})->data;
+        my $token_info =
+            $self->trello_client->get( 'tokens/' . $conf->{token} )->data;
         if ( $token_info->{dateExpires} ) {
             say "Token valid until: " . $token_info->{dateExpires};
         }
@@ -355,7 +360,11 @@ sub _trello_update_config {
 sub _trello_fetch_card {
     my ( $self, $trello_tag ) = @_;
 
-    my %search = ( query => $trello_tag, card_fields => 'shortLink', modelTypes=>'cards' );
+    my %search = (
+        query       => $trello_tag,
+        card_fields => 'shortLink',
+        modelTypes  => 'cards'
+    );
     if ( my $board_id = $self->config->{trello}{board_id} ) {
         $search{idBoards} = $board_id;
     }
@@ -404,6 +413,16 @@ sub _trello_just_the_name {
     return $name;
 }
 
+sub _tag_listname {
+    my ( $self, $card ) = @_;
+
+    my $list_id = $card->{idList};
+    return unless $list_id;
+    my $rv = $self->_do_trello( 'get', 'lists/' . $list_id . '/name' );
+    my $name = $rv->{_value};
+    $self->insert_tag($name) if $name;
+}
+
 sub App::TimeTracker::Data::Task::trello_card_id {
     my $self = shift;
     foreach my $tag ( @{ $self->tags } ) {
@@ -427,7 +446,7 @@ App::TimeTracker::Command::Trello - App::TimeTracker Trello plugin
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 DESCRIPTION
 
@@ -485,7 +504,7 @@ hard to get from trello, so use C<tracker setup_trello>.
 
 =head3 update_time_worked
 
-If set, updates the time worked on this task on the Trello Card.
+If set to true, updates the time worked on this task on the Trello Card.
 
 As Trello does not provide time-tracking (yet?), we store the
 time-worked in some simple markup in the Card name:
@@ -494,6 +513,15 @@ time-worked in some simple markup in the Card name:
 
 C<[w:32m]> means that you worked 32 minutes on the task.
 
+Context: stopish commands
+
+=head3 listname_as_tag
+
+If set to true, will fetch the name of the list the current card
+belongs to and store the name as an additional tag.
+
+Context: startish commands
+
 =head1 NEW COMMANDS
 
 =head2 setup_trello
@@ -549,6 +577,8 @@ If C<--trello> is set and we can find a card with this id:
 id. If you don't have access to the URL, click the 'Share and more'
 link (rather hard to find in the bottom right corner of a card).
 
+If C<listname_as_tag> is set, will store the name of the card's list as a tag.
+
 =head2 stop
 
 =over
